@@ -24,7 +24,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 #include <gconf/gconf-client.h>
 
 #include "egg-debug.h"
@@ -51,61 +51,68 @@ gpk_dialog_package_id_name_join_locale (gchar **package_ids)
 	guint i;
 	guint length;
 	gchar *text;
-	PkPackageId *ident;
 	GPtrArray *array;
 	gchar **array_strv;
+	gchar **split;
 
 	length = g_strv_length (package_ids);
-	array = g_ptr_array_new ();
+	array = g_ptr_array_new_with_free_func (g_free);
 	for (i=0; i<length; i++) {
-		ident = pk_package_id_new_from_string (package_ids[i]);
-		if (ident == NULL) {
+		split = pk_package_id_split (package_ids[i]);
+		if (split == NULL) {
 			egg_warning ("failed to split %s", package_ids[i]);
 			continue;
 		}
-		g_ptr_array_add (array, g_strdup (ident->name));
-		pk_package_id_free (ident);
+		g_ptr_array_add (array, g_strdup (split[0]));
+		g_strfreev (split);
 	}
 	array_strv = pk_ptr_array_to_strv (array);
 	text = gpk_strv_join_locale (array_strv);
 	g_strfreev (array_strv);
-	if (text == NULL)
+	if (text == NULL) {
+		/* TRANSLATORS: This is when we have over 5 items, and we're not interested in detail */
 		text = g_strdup (_("many packages"));
-	g_ptr_array_foreach (array, (GFunc) g_free, NULL);
-	g_ptr_array_free (array, TRUE);
+	}
+	g_ptr_array_unref (array);
 	return text;
 }
 
 /**
- * gpk_dialog_package_list_to_list_store:
+ * gpk_dialog_package_array_to_list_store:
  **/
 static GtkListStore *
-gpk_dialog_package_list_to_list_store (PkPackageList *list)
+gpk_dialog_package_array_to_list_store (GPtrArray *array)
 {
 	GtkListStore *store;
 	GtkTreeIter iter;
-	const PkPackageObj *obj;
+	PkPackage *item;
 	PkDesktop *desktop;
 	const gchar *icon;
-	gchar *package_id;
 	gchar *text;
-	guint length;
 	guint i;
+	gchar **split;
+	PkInfoEnum info;
+	gchar *package_id = NULL;
+	gchar *summary = NULL;
 
 	desktop = pk_desktop_new ();
 	store = gtk_list_store_new (GPK_DIALOG_STORE_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
-	length = pk_package_list_get_size (list);
 
 	/* add each well */
-	for (i=0; i<length; i++) {
-		obj = pk_package_list_get_obj (list, i);
-		text = gpk_package_id_format_twoline (obj->id, obj->summary);
-		package_id = pk_package_id_to_string (obj->id);
+	for (i=0; i<array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		g_object_get (item,
+			      "info", &info,
+			      "package-id", &package_id,
+			      "summary", &summary,
+			      NULL);
+		text = gpk_package_id_format_twoline (package_id, summary);
 
 		/* get the icon */
-		icon = gpk_desktop_guess_icon_name (desktop, obj->id->name);
+		split = pk_package_id_split (package_id);
+		icon = gpk_desktop_guess_icon_name (desktop, split[0]);
 		if (icon == NULL)
-			icon = gpk_info_enum_to_icon_name (PK_INFO_ENUM_INSTALLED);
+			icon = gpk_info_enum_to_icon_name (info);
 
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
@@ -113,8 +120,10 @@ gpk_dialog_package_list_to_list_store (PkPackageList *list)
 				    GPK_DIALOG_STORE_ID, package_id,
 				    GPK_DIALOG_STORE_TEXT, text,
 				    -1);
-		g_free (text);
+		g_strfreev (split);
 		g_free (package_id);
+		g_free (summary);
+		g_free (text);
 	}
 
 	g_object_unref (desktop);
@@ -168,15 +177,15 @@ gpk_dialog_widget_unrealize_unref_cb (GtkWidget *widget, GObject *obj)
  * gpk_dialog_embed_package_list_widget:
  **/
 gboolean
-gpk_dialog_embed_package_list_widget (GtkDialog *dialog, PkPackageList *list)
+gpk_dialog_embed_package_list_widget (GtkDialog *dialog, GPtrArray *array)
 {
 	GtkWidget *scroll;
 	GtkListStore *store;
 	GtkWidget *widget;
-	guint length;
+	const guint row_height = 48;
 
 	/* convert to a store */
-	store = gpk_dialog_package_list_to_list_store (list);
+	store = gpk_dialog_package_array_to_list_store (array);
 
 	/* create a treeview to hold the store */
 	widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
@@ -192,14 +201,19 @@ gpk_dialog_embed_package_list_widget (GtkDialog *dialog, PkPackageList *list)
 	/* add some spacing to conform to the GNOME HIG */
 	gtk_container_set_border_width (GTK_CONTAINER (scroll), 6);
 
-	length = pk_package_list_get_size (list);
-	if (length > 5) {
-		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, 300);
-	} else if (length > 1) {
-		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, 150);
+	/* only allow more space if there are a large number of items */
+	if (array->len > 5) {
+		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, (row_height * 5) + 8);
+	} else if (array->len > 1) {
+		gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, (row_height * array->len) + 8);
 	}
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), scroll);
+	/* add scrolled window */
+	widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
+	gtk_container_add_with_properties (GTK_CONTAINER (widget), scroll,
+					   "expand", TRUE,
+					   "fill", TRUE,
+					   NULL);
 
 	/* free the store */
 	g_signal_connect (G_OBJECT (dialog), "unrealize",
@@ -238,7 +252,7 @@ gpk_dialog_embed_file_list_widget (GtkDialog *dialog, GPtrArray *files)
 	/* scroll the treeview */
 	scroll = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
-					GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scroll), widget);
 	gtk_widget_show (scroll);
 
@@ -252,7 +266,9 @@ gpk_dialog_embed_file_list_widget (GtkDialog *dialog, GPtrArray *files)
 	gtk_container_set_border_width (GTK_CONTAINER (scroll), 6);
 	gtk_widget_set_size_request (GTK_WIDGET (scroll), -1, 300);
 
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox), scroll);
+	/* add scrolled window */
+	widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
+	gtk_container_add (GTK_CONTAINER (widget), scroll);
 	g_free (text);
 
 	return TRUE;
@@ -271,7 +287,7 @@ gpk_client_checkbutton_show_depends_cb (GtkWidget *widget, const gchar *key)
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 	egg_debug ("Changing %s to %i", key, checked);
 	gconf_client = gconf_client_get_default ();
-	gconf_client_set_bool (gconf_client, key, checked, NULL);
+	gconf_client_set_bool (gconf_client, key, !checked, NULL);
 	g_object_unref (gconf_client);
 }
 
@@ -281,13 +297,27 @@ gpk_client_checkbutton_show_depends_cb (GtkWidget *widget, const gchar *key)
 gboolean
 gpk_dialog_embed_do_not_show_widget (GtkDialog *dialog, const gchar *key)
 {
+	GtkWidget *check_button;
 	GtkWidget *widget;
+	gboolean checked;
+	GConfClient *gconf_client;
 
 	/* add a checkbutton for deps screen */
-	widget = gtk_check_button_new_with_label (_("Do not show this again"));
-	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_client_checkbutton_show_depends_cb), (gpointer) key);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), widget);
-	gtk_widget_show (widget);
+	check_button = gtk_check_button_new_with_label (_("Do not show this again"));
+	g_signal_connect (check_button, "clicked", G_CALLBACK (gpk_client_checkbutton_show_depends_cb), (gpointer) key);
+	widget = gtk_dialog_get_content_area (GTK_DIALOG(dialog));
+	gtk_container_add_with_properties (GTK_CONTAINER (widget), check_button,
+					   "expand", FALSE,
+					   "fill", FALSE,
+					   NULL);
+
+	/* checked? */
+	gconf_client = gconf_client_get_default ();
+	checked = gconf_client_get_bool (gconf_client, key, NULL);
+	g_object_unref (gconf_client);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check_button), !checked);
+
+	gtk_widget_show (check_button);
 	return TRUE;
 }
 
